const CSS_ID = 'jbits-custom-styles'; // Unique ID for our injected CSS

function generateCSS(settings) {
    // Use template literals for easier string formatting
    return `
        TR.CRT TD { background: ${settings.crtColor} !important; }
        TR.DEF TD { background: ${settings.defColor} !important; }
        TR.PTF TD { background: ${settings.ptfColor} !important; }
        .DEF.dt-hasChild TD { height: auto !important; } /* Keep original static style */

        /* Styles using detailBgColor and detailFontSize */
        .col-auto:nth-child(3) dd:nth-child(4),
        .col-md-6 dt:nth-child(1),
        .col-md-6 dd:nth-child(2) {
            background: ${settings.detailBgColor} !important;
            font-weight: bold !important; /* Keep original static style */
            font-size: ${settings.detailFontSize}pt !important;
        }
    `;
}

async function applyStyles() {
    const data = await chrome.storage.sync.get('jbitsStylerSettings');
    const defaultSettings = { // Keep defaults consistent with options.js
        crtColor: '#FFFFC5',
        defColor: '#90EE90',
        ptfColor: '#FF746C',
        detailBgColor: '#90EE90',
        detailFontSize: 14
    };
    const currentSettings = { ...defaultSettings, ...data.jbitsStylerSettings };
    const css = generateCSS(currentSettings);

    // Remove previous styles if they exist
    try {
        await chrome.scripting.removeCSS({
            target: { tabId: await getCurrentTabId() }, // Needs tab ID
            id: CSS_ID
        });
    } catch (e) {
        // Ignore errors (e.g., if CSS wasn't injected yet)
        // console.debug("No previous CSS to remove or error removing:", e);
    }

    // Insert the new styles
    try {
         await chrome.scripting.insertCSS({
            target: { tabId: await getCurrentTabId() }, // Needs tab ID
            css: css,
            origin: "USER", // Important for !important rules often
            id: CSS_ID // Assign an ID
        });
         console.log("JBITS Styler: Styles applied.");
    } catch (e) {
        console.error("JBITS Styler: Error inserting CSS:", e);
    }
}

// Helper function to get current tab ID (required for scripting API target)
// This is tricky in content scripts. We'll rely on the background script
// sending a message *with* the tab ID when changes occur.
// For the initial load, we can request the ID.

// We need a way to get the tab ID *reliably* for scripting.insertCSS/removeCSS
// The best way is often via messages from the background script or popup.
// Let's simplify for initial load and rely on background message for updates.
// *** Initial application might require a different approach if background isn't active yet ***
// Let's try applying styles directly on load, assuming the content script knows its context.

// Simplified applyStyles for initial load (doesn't need tab ID explicitly here)
async function applyInitialStyles() {
    const data = await chrome.storage.sync.get('jbitsStylerSettings');
    const defaultSettings = { // Keep defaults consistent with options.js
        crtColor: '#FFFFC5',
        defColor: '#90EE90',
        ptfColor: '#FF746C',
        detailBgColor: '#90EE90',
        detailFontSize: 14
    };
    const currentSettings = { ...defaultSettings, ...data.jbitsStylerSettings };
    const css = generateCSS(currentSettings);

    // Inject CSS directly without needing tabId (content script context)
    // Check if style element already exists
    let styleElement = document.getElementById(CSS_ID);
    if (!styleElement) {
        styleElement = document.createElement('style');
        styleElement.id = CSS_ID;
        document.head.appendChild(styleElement);
    }
    styleElement.textContent = css;
    console.log("JBITS Styler: Initial styles applied via <style> tag.");
}


// Listen for messages from the background script (e.g., when settings change)
chrome.runtime.onMessage.addListener((message, sender, sendResponse) => {
    if (message.type === 'UPDATE_STYLES') {
        console.log("JBITS Styler: Received style update request.");
        applyInitialStyles(); // Re-apply using the <style> tag method
        sendResponse({ status: "Styles updated on page" });
    }
    return true; // Keep the message channel open for asynchronous response if needed
});

// Apply styles when the script first loads
applyInitialStyles();